GetPermitNumberSearchData
^^^^^^^^^^^^^^^^^^^^^^^^^

`GetPermitNumberSearchData?PERMITNO=15947,95787,5928 <https://www.waterconnect.sa.gov.au/_layouts/15/dfw.sharepoint.wdd/WDDDMS.ashx/GetPermitNumberSearchData?PERMITNO=15947,95787,5928>`__

Returns a JSON array of objects:

.. code-block:: json

    [
      {
        "DHNO": 4160,
        "LAT": -32.8590944,
        "LON": 134.4099006,
        "MAPNUM": 573200173,
        "MAX_DEPTH": 19.3,
        "PERMIT_NO": 15947,
        "PURP_DESC": "DOM",
        "SWL": 16.8,
        "YIELD": 0.25,
        "TDS": 716,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Eyre Peninsula",
        "LOGDRILL": "Y",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "N",
        "STRATLOG": "N",
        "HSTRATLOG": "N",
        "LATEST_SWL_DATE": "1985-03-20",
        "LATEST_SAL_DATE": "1985-03-20",
        "LATEST_YIELD_DATE": "1985-03-20",
        "LATEST_OPEN_DEPTH": 19.3,
        "LATEST_OPEN_DATE": "1985-03-20"
      },
      {
        "DHNO": 5175,
        "LAT": -28.4466172,
        "LON": 134.2679997,
        "MAPNUM": 574100048,
        "MAX_DEPTH": 147.2,
        "PERMIT_NO": 95787,
        "DRILL_DATE": "1991-06-04",
        "PURP_DESC": "STK",
        "AQ_MON": "JK1",
        "SWL": 0,
        "STAT_DESC": "BKF",
        "CLASS": "WW",
        "PWA": "Far North",
        "NRM": "South Australian Arid Lands",
        "LOGDRILL": "N",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "N",
        "OBSWELL": "N",
        "STRATLOG": "N",
        "HSTRATLOG": "Y",
        "LATEST_OPEN_DEPTH": 0,
        "LATEST_OPEN_DATE": "1991-06-04"
      },
      {
        "NAME": "LOWER YORKE PENINSULA",
        "DHNO": 18962,
        "LAT": -35.097168,
        "LON": 137.1529782,
        "MAPNUM": 632700368,
        "MAX_DEPTH": 83.5,
        "PERMIT_NO": 5928,
        "DRILL_DATE": "1979-11-01",
        "PURP_DESC": "STK",
        "AQ_MON": "L",
        "SWL": 14,
        "YIELD": 0.13,
        "TDS": 1759,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Northern & Yorke",
        "LOGDRILL": "Y",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "N",
        "STRATLOG": "N",
        "HSTRATLOG": "Y",
        "LATEST_SWL_DATE": "1979-11-01",
        "LATEST_SAL_DATE": "1979-11-01",
        "LATEST_YIELD_DATE": "1979-11-01",
        "LATEST_OPEN_DEPTH": 83.5,
        "LATEST_OPEN_DATE": "1979-11-01"
      }
    ]
